SocketEvent

Enum SocketEvent 

pub enum SocketEvent {
    Packet(Packet),
    Connect(SocketAddr),
    Timeout(SocketAddr),
    Disconnect(SocketAddr),
}
Events that can occur and are pushed through the event_receiver. These are user-facing events emitted by the socket/connection manager.

Variants



Packet(Packet)

A packet was received from a client.



Connect(SocketAddr)

A new connection has been established.



Timeout(SocketAddr)

The client has been idling longer than the idle_connection_timeout.



Disconnect(SocketAddr)

The established connection to a client has timed out.