SessionManager

Struct SessionManager 

pub struct SessionManager<TSocket: TransportSocket, TSession: Session> { /* private fields */ }
Session manager over a datagram socket and generic Session engine.

Implementations

Source

impl<TSocket: TransportSocket, TSession: Session> SessionManager<TSocket, TSession>

pub fn new(socket: TSocket, config: Config) -> Self

Creates a new session manager.

pub fn new_with_interceptor( socket: TSocket, config: Config, interceptor: Option<Box<dyn Interceptor>>, ) -> Self

Creates a new session manager with a custom interceptor.

pub fn manual_poll(&mut self, time: Instant)

Polls for network I/O and processes all sessions.

pub fn event_sender(&self) -> &Sender<TSession::SendEvent>

Returns the event sender for sending user events to sessions.

pub fn event_receiver(&self) -> &Receiver<TSession::ReceiveEvent>

Returns the event receiver for receiving session events.

pub fn socket(&self) -> &TSocket

Returns a reference to the underlying socket.

pub fn socket_mut(&mut self) -> &mut TSocket

Returns a mutable reference to the underlying socket.

pub fn sessions_count(&self) -> usize

Returns the number of active sessions.

pub fn session_mut(&mut self, addr: &SocketAddr) -> Option<&mut TSession>

Returns a mutable reference to a specific session by address.

pub fn established_sessions(&self) -> impl Iterator<Item = &SocketAddr>

Returns an iterator over all established session addresses.

pub fn established_sessions_count(&self) -> usize

Returns the number of established sessions.

pub fn duplicate_peer_count(&self, addr: &SocketAddr) -> usize

Returns the number of connections from a specific IP address.